# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from mett_dataportal_sdk.models.paginated_response_schema import PaginatedResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class DrugsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchema:
        """Get metabolism data by drug name

        Retrieves metabolism data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_with_http_info(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchema]:
        """Get metabolism data by drug name

        Retrieves metabolism data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_without_preload_content(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get metabolism data by drug name

        Retrieves metabolism data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_drug_endpoints_get_drug_metabolism_by_drug_serialize(
        self,
        drug_name,
        species_acronym,
        page,
        per_page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if drug_name is not None:
            _path_params["drug_name"] = drug_name
        # process the query parameters
        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/drugs/metabolism/by-drug/{drug_name}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchema:
        """Get MIC data by drug name

        Retrieves MIC data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_with_http_info(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchema]:
        """Get MIC data by drug name

        Retrieves MIC data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_without_preload_content(
        self,
        drug_name: Annotated[StrictStr, Field(description="Name of the drug")],
        species_acronym: Annotated[
            Optional[StrictStr],
            Field(description="Optional species acronym filter (BU, PV)"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100, strict=True, ge=1)]],
            Field(description="Number of results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get MIC data by drug name

        Retrieves MIC data for a specific drug across all strains. Supports pagination and optional species filtering.

        :param drug_name: Name of the drug (required)
        :type drug_name: str
        :param species_acronym: Optional species acronym filter (BU, PV)
        :type species_acronym: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_serialize(
            drug_name=drug_name,
            species_acronym=species_acronym,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_drug_endpoints_get_drug_mic_by_drug_serialize(
        self,
        drug_name,
        species_acronym,
        page,
        per_page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if drug_name is not None:
            _path_params["drug_name"] = drug_name
        # process the query parameters
        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/drugs/mic/by-drug/{drug_name}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_metabolism(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_fdr: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum FDR threshold (e.g., 0.05)"),
        ] = None,
        min_degr_percent: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum degradation percentage"),
        ] = None,
        metabolizer_classification: Annotated[
            Optional[StrictStr],
            Field(description="Filter by metabolizer classification"),
        ] = None,
        is_significant: Annotated[
            Optional[StrictBool],
            Field(description="Filter by statistical significance"),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchema:
        """Search drug metabolism data

        Search drug metabolism data across all strains. Supports filtering by drug name, class, species, statistical significance, degradation percentages, and experimental conditions. Returns paginated results with detailed metabolism measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_fdr: Maximum FDR threshold (e.g., 0.05)
        :type min_fdr: float
        :param min_degr_percent: Minimum degradation percentage
        :type min_degr_percent: float
        :param metabolizer_classification: Filter by metabolizer classification
        :type metabolizer_classification: str
        :param is_significant: Filter by statistical significance
        :type is_significant: bool
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_search_drug_metabolism_serialize(
            query=query,
            drug_name=drug_name,
            drug_class=drug_class,
            species_acronym=species_acronym,
            min_fdr=min_fdr,
            min_degr_percent=min_degr_percent,
            metabolizer_classification=metabolizer_classification,
            is_significant=is_significant,
            experimental_condition=experimental_condition,
            page=page,
            per_page=per_page,
            sort_by=sort_by,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_metabolism_with_http_info(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_fdr: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum FDR threshold (e.g., 0.05)"),
        ] = None,
        min_degr_percent: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum degradation percentage"),
        ] = None,
        metabolizer_classification: Annotated[
            Optional[StrictStr],
            Field(description="Filter by metabolizer classification"),
        ] = None,
        is_significant: Annotated[
            Optional[StrictBool],
            Field(description="Filter by statistical significance"),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchema]:
        """Search drug metabolism data

        Search drug metabolism data across all strains. Supports filtering by drug name, class, species, statistical significance, degradation percentages, and experimental conditions. Returns paginated results with detailed metabolism measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_fdr: Maximum FDR threshold (e.g., 0.05)
        :type min_fdr: float
        :param min_degr_percent: Minimum degradation percentage
        :type min_degr_percent: float
        :param metabolizer_classification: Filter by metabolizer classification
        :type metabolizer_classification: str
        :param is_significant: Filter by statistical significance
        :type is_significant: bool
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_search_drug_metabolism_serialize(
            query=query,
            drug_name=drug_name,
            drug_class=drug_class,
            species_acronym=species_acronym,
            min_fdr=min_fdr,
            min_degr_percent=min_degr_percent,
            metabolizer_classification=metabolizer_classification,
            is_significant=is_significant,
            experimental_condition=experimental_condition,
            page=page,
            per_page=per_page,
            sort_by=sort_by,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_metabolism_without_preload_content(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_fdr: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum FDR threshold (e.g., 0.05)"),
        ] = None,
        min_degr_percent: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum degradation percentage"),
        ] = None,
        metabolizer_classification: Annotated[
            Optional[StrictStr],
            Field(description="Filter by metabolizer classification"),
        ] = None,
        is_significant: Annotated[
            Optional[StrictBool],
            Field(description="Filter by statistical significance"),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search drug metabolism data

        Search drug metabolism data across all strains. Supports filtering by drug name, class, species, statistical significance, degradation percentages, and experimental conditions. Returns paginated results with detailed metabolism measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_fdr: Maximum FDR threshold (e.g., 0.05)
        :type min_fdr: float
        :param min_degr_percent: Minimum degradation percentage
        :type min_degr_percent: float
        :param metabolizer_classification: Filter by metabolizer classification
        :type metabolizer_classification: str
        :param is_significant: Filter by statistical significance
        :type is_significant: bool
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_drug_endpoints_search_drug_metabolism_serialize(
            query=query,
            drug_name=drug_name,
            drug_class=drug_class,
            species_acronym=species_acronym,
            min_fdr=min_fdr,
            min_degr_percent=min_degr_percent,
            metabolizer_classification=metabolizer_classification,
            is_significant=is_significant,
            experimental_condition=experimental_condition,
            page=page,
            per_page=per_page,
            sort_by=sort_by,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_drug_endpoints_search_drug_metabolism_serialize(
        self,
        query,
        drug_name,
        drug_class,
        species_acronym,
        min_fdr,
        min_degr_percent,
        metabolizer_classification,
        is_significant,
        experimental_condition,
        page,
        per_page,
        sort_by,
        sort_order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if drug_name is not None:
            _query_params.append(("drug_name", drug_name))

        if drug_class is not None:
            _query_params.append(("drug_class", drug_class))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if min_fdr is not None:
            _query_params.append(("min_fdr", min_fdr))

        if min_degr_percent is not None:
            _query_params.append(("min_degr_percent", min_degr_percent))

        if metabolizer_classification is not None:
            _query_params.append(
                ("metabolizer_classification", metabolizer_classification)
            )

        if is_significant is not None:
            _query_params.append(("is_significant", is_significant))

        if experimental_condition is not None:
            _query_params.append(("experimental_condition", experimental_condition))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_by is not None:
            _query_params.append(("sort_by", sort_by))

        if sort_order is not None:
            _query_params.append(("sort_order", sort_order))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/drugs/metabolism/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_mic(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum MIC value threshold"),
        ] = None,
        max_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum MIC value threshold"),
        ] = None,
        unit: Annotated[
            Optional[StrictStr], Field(description="Filter by unit (uM, mg/L)")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchema:
        """Search drug MIC data

        Search drug MIC (Minimum Inhibitory Concentration) data across all strains. Supports filtering by drug name, class, species, MIC values, and experimental conditions. Returns paginated results with detailed MIC measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_mic_value: Minimum MIC value threshold
        :type min_mic_value: float
        :param max_mic_value: Maximum MIC value threshold
        :type max_mic_value: float
        :param unit: Filter by unit (uM, mg/L)
        :type unit: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_experimental_drug_endpoints_search_drug_mic_serialize(
                query=query,
                drug_name=drug_name,
                drug_class=drug_class,
                species_acronym=species_acronym,
                min_mic_value=min_mic_value,
                max_mic_value=max_mic_value,
                unit=unit,
                experimental_condition=experimental_condition,
                page=page,
                per_page=per_page,
                sort_by=sort_by,
                sort_order=sort_order,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_mic_with_http_info(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum MIC value threshold"),
        ] = None,
        max_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum MIC value threshold"),
        ] = None,
        unit: Annotated[
            Optional[StrictStr], Field(description="Filter by unit (uM, mg/L)")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchema]:
        """Search drug MIC data

        Search drug MIC (Minimum Inhibitory Concentration) data across all strains. Supports filtering by drug name, class, species, MIC values, and experimental conditions. Returns paginated results with detailed MIC measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_mic_value: Minimum MIC value threshold
        :type min_mic_value: float
        :param max_mic_value: Maximum MIC value threshold
        :type max_mic_value: float
        :param unit: Filter by unit (uM, mg/L)
        :type unit: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_experimental_drug_endpoints_search_drug_mic_serialize(
                query=query,
                drug_name=drug_name,
                drug_class=drug_class,
                species_acronym=species_acronym,
                min_mic_value=min_mic_value,
                max_mic_value=max_mic_value,
                unit=unit,
                experimental_condition=experimental_condition,
                page=page,
                per_page=per_page,
                sort_by=sort_by,
                sort_order=sort_order,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_drug_endpoints_search_drug_mic_without_preload_content(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term for drug name, class, or strain"),
        ] = None,
        drug_name: Annotated[
            Optional[StrictStr], Field(description="Filter by specific drug name")
        ] = None,
        drug_class: Annotated[
            Optional[StrictStr], Field(description="Filter by drug class")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Filter by species acronym")
        ] = None,
        min_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum MIC value threshold"),
        ] = None,
        max_mic_value: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Maximum MIC value threshold"),
        ] = None,
        unit: Annotated[
            Optional[StrictStr], Field(description="Filter by unit (uM, mg/L)")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        per_page: Annotated[
            Optional[StrictInt], Field(description="Number of results per page")
        ] = None,
        sort_by: Annotated[
            Optional[StrictStr],
            Field(
                description="Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order (asc, desc)")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search drug MIC data

        Search drug MIC (Minimum Inhibitory Concentration) data across all strains. Supports filtering by drug name, class, species, MIC values, and experimental conditions. Returns paginated results with detailed MIC measurements. Note: Sorting is limited to top-level fields (isolate_name, species_acronym, species_scientific_name).

        :param query: Search term for drug name, class, or strain
        :type query: str
        :param drug_name: Filter by specific drug name
        :type drug_name: str
        :param drug_class: Filter by drug class
        :type drug_class: str
        :param species_acronym: Filter by species acronym
        :type species_acronym: str
        :param min_mic_value: Minimum MIC value threshold
        :type min_mic_value: float
        :param max_mic_value: Maximum MIC value threshold
        :type max_mic_value: float
        :param unit: Filter by unit (uM, mg/L)
        :type unit: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param page: Page number
        :type page: int
        :param per_page: Number of results per page
        :type per_page: int
        :param sort_by: Sort field (isolate_name, species_acronym, species_scientific_name). Uses keyword fields for sorting.
        :type sort_by: str
        :param sort_order: Sort order (asc, desc)
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_experimental_drug_endpoints_search_drug_mic_serialize(
                query=query,
                drug_name=drug_name,
                drug_class=drug_class,
                species_acronym=species_acronym,
                min_mic_value=min_mic_value,
                max_mic_value=max_mic_value,
                unit=unit,
                experimental_condition=experimental_condition,
                page=page,
                per_page=per_page,
                sort_by=sort_by,
                sort_order=sort_order,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_drug_endpoints_search_drug_mic_serialize(
        self,
        query,
        drug_name,
        drug_class,
        species_acronym,
        min_mic_value,
        max_mic_value,
        unit,
        experimental_condition,
        page,
        per_page,
        sort_by,
        sort_order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if drug_name is not None:
            _query_params.append(("drug_name", drug_name))

        if drug_class is not None:
            _query_params.append(("drug_class", drug_class))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if min_mic_value is not None:
            _query_params.append(("min_mic_value", min_mic_value))

        if max_mic_value is not None:
            _query_params.append(("max_mic_value", max_mic_value))

        if unit is not None:
            _query_params.append(("unit", unit))

        if experimental_condition is not None:
            _query_params.append(("experimental_condition", experimental_condition))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_by is not None:
            _query_params.append(("sort_by", sort_by))

        if sort_order is not None:
            _query_params.append(("sort_order", sort_order))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/drugs/mic/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Set
from typing_extensions import Self


class PPIInteractionSchema(BaseModel):
    """
    Schema for a single PPI interaction.
    """  # noqa: E501

    pair_id: StrictStr
    species_scientific_name: Optional[StrictStr] = None
    species_acronym: Optional[StrictStr] = None
    isolate_name: Optional[StrictStr] = None
    protein_a: StrictStr
    protein_b: StrictStr
    participants: List[StrictStr]
    is_self_interaction: Optional[StrictBool] = False
    protein_a_locus_tag: Optional[StrictStr] = None
    protein_a_uniprot_id: Optional[StrictStr] = None
    protein_a_name: Optional[StrictStr] = None
    protein_a_product: Optional[StrictStr] = None
    protein_b_locus_tag: Optional[StrictStr] = None
    protein_b_uniprot_id: Optional[StrictStr] = None
    protein_b_name: Optional[StrictStr] = None
    protein_b_product: Optional[StrictStr] = None
    dl_score: Optional[Union[StrictFloat, StrictInt]] = None
    comelt_score: Optional[Union[StrictFloat, StrictInt]] = None
    perturbation_score: Optional[Union[StrictFloat, StrictInt]] = None
    abundance_score: Optional[Union[StrictFloat, StrictInt]] = None
    melt_score: Optional[Union[StrictFloat, StrictInt]] = None
    secondary_score: Optional[Union[StrictFloat, StrictInt]] = None
    bayesian_score: Optional[Union[StrictFloat, StrictInt]] = None
    string_score: Optional[Union[StrictFloat, StrictInt]] = None
    operon_score: Optional[Union[StrictFloat, StrictInt]] = None
    ecocyc_score: Optional[Union[StrictFloat, StrictInt]] = None
    tt_score: Optional[Union[StrictFloat, StrictInt]] = None
    ds_score: Optional[Union[StrictFloat, StrictInt]] = None
    has_xlms: Optional[StrictBool] = False
    has_string: Optional[StrictBool] = False
    has_operon: Optional[StrictBool] = False
    has_ecocyc: Optional[StrictBool] = False
    evidence_count: Optional[StrictInt] = 0
    __properties: ClassVar[List[str]] = [
        "pair_id",
        "species_scientific_name",
        "species_acronym",
        "isolate_name",
        "protein_a",
        "protein_b",
        "participants",
        "is_self_interaction",
        "protein_a_locus_tag",
        "protein_a_uniprot_id",
        "protein_a_name",
        "protein_a_product",
        "protein_b_locus_tag",
        "protein_b_uniprot_id",
        "protein_b_name",
        "protein_b_product",
        "dl_score",
        "comelt_score",
        "perturbation_score",
        "abundance_score",
        "melt_score",
        "secondary_score",
        "bayesian_score",
        "string_score",
        "operon_score",
        "ecocyc_score",
        "tt_score",
        "ds_score",
        "has_xlms",
        "has_string",
        "has_operon",
        "has_ecocyc",
        "evidence_count",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PPIInteractionSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if species_scientific_name (nullable) is None
        # and model_fields_set contains the field
        if (
            self.species_scientific_name is None
            and "species_scientific_name" in self.model_fields_set
        ):
            _dict["species_scientific_name"] = None

        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if isolate_name (nullable) is None
        # and model_fields_set contains the field
        if self.isolate_name is None and "isolate_name" in self.model_fields_set:
            _dict["isolate_name"] = None

        # set to None if protein_a_locus_tag (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_a_locus_tag is None
            and "protein_a_locus_tag" in self.model_fields_set
        ):
            _dict["protein_a_locus_tag"] = None

        # set to None if protein_a_uniprot_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_a_uniprot_id is None
            and "protein_a_uniprot_id" in self.model_fields_set
        ):
            _dict["protein_a_uniprot_id"] = None

        # set to None if protein_a_name (nullable) is None
        # and model_fields_set contains the field
        if self.protein_a_name is None and "protein_a_name" in self.model_fields_set:
            _dict["protein_a_name"] = None

        # set to None if protein_a_product (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_a_product is None
            and "protein_a_product" in self.model_fields_set
        ):
            _dict["protein_a_product"] = None

        # set to None if protein_b_locus_tag (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_b_locus_tag is None
            and "protein_b_locus_tag" in self.model_fields_set
        ):
            _dict["protein_b_locus_tag"] = None

        # set to None if protein_b_uniprot_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_b_uniprot_id is None
            and "protein_b_uniprot_id" in self.model_fields_set
        ):
            _dict["protein_b_uniprot_id"] = None

        # set to None if protein_b_name (nullable) is None
        # and model_fields_set contains the field
        if self.protein_b_name is None and "protein_b_name" in self.model_fields_set:
            _dict["protein_b_name"] = None

        # set to None if protein_b_product (nullable) is None
        # and model_fields_set contains the field
        if (
            self.protein_b_product is None
            and "protein_b_product" in self.model_fields_set
        ):
            _dict["protein_b_product"] = None

        # set to None if dl_score (nullable) is None
        # and model_fields_set contains the field
        if self.dl_score is None and "dl_score" in self.model_fields_set:
            _dict["dl_score"] = None

        # set to None if comelt_score (nullable) is None
        # and model_fields_set contains the field
        if self.comelt_score is None and "comelt_score" in self.model_fields_set:
            _dict["comelt_score"] = None

        # set to None if perturbation_score (nullable) is None
        # and model_fields_set contains the field
        if (
            self.perturbation_score is None
            and "perturbation_score" in self.model_fields_set
        ):
            _dict["perturbation_score"] = None

        # set to None if abundance_score (nullable) is None
        # and model_fields_set contains the field
        if self.abundance_score is None and "abundance_score" in self.model_fields_set:
            _dict["abundance_score"] = None

        # set to None if melt_score (nullable) is None
        # and model_fields_set contains the field
        if self.melt_score is None and "melt_score" in self.model_fields_set:
            _dict["melt_score"] = None

        # set to None if secondary_score (nullable) is None
        # and model_fields_set contains the field
        if self.secondary_score is None and "secondary_score" in self.model_fields_set:
            _dict["secondary_score"] = None

        # set to None if bayesian_score (nullable) is None
        # and model_fields_set contains the field
        if self.bayesian_score is None and "bayesian_score" in self.model_fields_set:
            _dict["bayesian_score"] = None

        # set to None if string_score (nullable) is None
        # and model_fields_set contains the field
        if self.string_score is None and "string_score" in self.model_fields_set:
            _dict["string_score"] = None

        # set to None if operon_score (nullable) is None
        # and model_fields_set contains the field
        if self.operon_score is None and "operon_score" in self.model_fields_set:
            _dict["operon_score"] = None

        # set to None if ecocyc_score (nullable) is None
        # and model_fields_set contains the field
        if self.ecocyc_score is None and "ecocyc_score" in self.model_fields_set:
            _dict["ecocyc_score"] = None

        # set to None if tt_score (nullable) is None
        # and model_fields_set contains the field
        if self.tt_score is None and "tt_score" in self.model_fields_set:
            _dict["tt_score"] = None

        # set to None if ds_score (nullable) is None
        # and model_fields_set contains the field
        if self.ds_score is None and "ds_score" in self.model_fields_set:
            _dict["ds_score"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PPIInteractionSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "pair_id": obj.get("pair_id"),
                "species_scientific_name": obj.get("species_scientific_name"),
                "species_acronym": obj.get("species_acronym"),
                "isolate_name": obj.get("isolate_name"),
                "protein_a": obj.get("protein_a"),
                "protein_b": obj.get("protein_b"),
                "participants": obj.get("participants"),
                "is_self_interaction": obj.get("is_self_interaction")
                if obj.get("is_self_interaction") is not None
                else False,
                "protein_a_locus_tag": obj.get("protein_a_locus_tag"),
                "protein_a_uniprot_id": obj.get("protein_a_uniprot_id"),
                "protein_a_name": obj.get("protein_a_name"),
                "protein_a_product": obj.get("protein_a_product"),
                "protein_b_locus_tag": obj.get("protein_b_locus_tag"),
                "protein_b_uniprot_id": obj.get("protein_b_uniprot_id"),
                "protein_b_name": obj.get("protein_b_name"),
                "protein_b_product": obj.get("protein_b_product"),
                "dl_score": obj.get("dl_score"),
                "comelt_score": obj.get("comelt_score"),
                "perturbation_score": obj.get("perturbation_score"),
                "abundance_score": obj.get("abundance_score"),
                "melt_score": obj.get("melt_score"),
                "secondary_score": obj.get("secondary_score"),
                "bayesian_score": obj.get("bayesian_score"),
                "string_score": obj.get("string_score"),
                "operon_score": obj.get("operon_score"),
                "ecocyc_score": obj.get("ecocyc_score"),
                "tt_score": obj.get("tt_score"),
                "ds_score": obj.get("ds_score"),
                "has_xlms": obj.get("has_xlms")
                if obj.get("has_xlms") is not None
                else False,
                "has_string": obj.get("has_string")
                if obj.get("has_string") is not None
                else False,
                "has_operon": obj.get("has_operon")
                if obj.get("has_operon") is not None
                else False,
                "has_ecocyc": obj.get("has_ecocyc")
                if obj.get("has_ecocyc") is not None
                else False,
                "evidence_count": obj.get("evidence_count")
                if obj.get("evidence_count") is not None
                else 0,
            }
        )
        return _obj



"""TTP (Pooled TTP Interactions) CLI commands."""

from __future__ import annotations

from typing import Optional

import typer  # type: ignore[import]

from ..utils import ensure_client, handle_raw_response, merge_params

ttp_app = typer.Typer(help="Pooled TTP interaction endpoints")


@ttp_app.command("metadata")
def ttp_metadata(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/ttp/metadata", format=format)
    handle_raw_response(response, format, title="TTP metadata")


@ttp_app.command("search")
def ttp_search(
    ctx: typer.Context,
    query: Optional[str] = typer.Option(None, "--query", "-q"),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "query": query,
            "page": page,
            "per_page": per_page,
            "sort_field": sort_field,
            "sort_order": sort_order,
        }
    )
    response = client.raw_request(
        "GET", "/api/ttp/search", params=params, format=format
    )
    handle_raw_response(response, format, title="TTP search")


@ttp_app.command("gene-interactions")
def ttp_gene_interactions(
    ctx: typer.Context,
    locus_tag: str = typer.Argument(...),
    hit_calling: Optional[bool] = typer.Option(None, "--hit-calling"),
    pool_a: Optional[str] = typer.Option(None, "--pool-a"),
    pool_b: Optional[str] = typer.Option(None, "--pool-b"),
    min_ttp_score: Optional[float] = typer.Option(None, "--min-ttp-score"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tag": locus_tag,
            "hit_calling": hit_calling,
            "poolA": pool_a,
            "poolB": pool_b,
            "min_ttp_score": min_ttp_score,
            "sort_field": sort_field,
            "sort_order": sort_order,
        }
    )
    response = client.raw_request(
        "GET",
        f"/api/ttp/gene/{locus_tag}/interactions",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"TTP interactions ({locus_tag})")


@ttp_app.command("compound-interactions")
def ttp_compound_interactions(
    ctx: typer.Context,
    compound: str = typer.Argument(...),
    hit_calling: Optional[bool] = typer.Option(None, "--hit-calling"),
    species_acronym: Optional[str] = typer.Option(None, "--species", "-s"),
    isolate_name: Optional[str] = typer.Option(None, "--isolate"),
    min_ttp_score: Optional[float] = typer.Option(None, "--min-ttp-score"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "compound": compound,
            "hit_calling": hit_calling,
            "species_acronym": species_acronym,
            "isolate_name": isolate_name,
            "min_ttp_score": min_ttp_score,
            "sort_field": sort_field,
            "sort_order": sort_order,
        }
    )
    response = client.raw_request(
        "GET",
        f"/api/ttp/compound/{compound}/interactions",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"TTP interactions ({compound})")


@ttp_app.command("hits")
def ttp_hits(
    ctx: typer.Context,
    min_ttp_score: Optional[float] = typer.Option(None, "--min-ttp-score"),
    max_fdr: Optional[float] = typer.Option(None, "--max-fdr"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params({"min_ttp_score": min_ttp_score, "max_fdr": max_fdr})
    response = client.raw_request("GET", "/api/ttp/hits", params=params, format=format)
    handle_raw_response(response, format, title="TTP hits")


@ttp_app.command("pools-analysis")
def ttp_pools_analysis(
    ctx: typer.Context,
    pool_a: str = typer.Option(..., "--pool-a"),
    pool_b: str = typer.Option(..., "--pool-b"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = {"poolA": pool_a, "poolB": pool_b}
    response = client.raw_request(
        "GET", "/api/ttp/pools/analysis", params=params, format=format
    )
    handle_raw_response(response, format, title="TTP pools analysis")



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mett_dataportal_sdk.models.amr_schema import AMRSchema
from mett_dataportal_sdk.models.dbx_ref_schema import DBXRefSchema
from typing import Set
from typing_extensions import Self


class GeneResponseSchema(BaseModel):
    """
    GeneResponseSchema
    """  # noqa: E501

    locus_tag: Optional[StrictStr] = None
    gene_name: Optional[StrictStr] = None
    alias: Optional[List[StrictStr]] = None
    product: Optional[StrictStr] = None
    product_source: Optional[StrictStr] = None
    start_position: Optional[StrictInt] = None
    end_position: Optional[StrictInt] = None
    seq_id: Optional[StrictStr] = None
    isolate_name: Optional[StrictStr] = None
    species_scientific_name: Optional[StrictStr] = None
    species_acronym: Optional[StrictStr] = None
    uniprot_id: Optional[StrictStr] = None
    essentiality: Optional[StrictStr] = None
    cog_funcats: Optional[List[StrictStr]] = None
    cog_id: Optional[List[StrictStr]] = None
    kegg: Optional[List[StrictStr]] = None
    pfam: Optional[List[StrictStr]] = None
    interpro: Optional[List[StrictStr]] = None
    ec_number: Optional[StrictStr] = None
    dbxref: Optional[List[DBXRefSchema]] = None
    eggnog: Optional[StrictStr] = None
    inference: Optional[StrictStr] = None
    ontology_terms: Optional[List[Dict[str, Any]]] = None
    uf_ontology_terms: Optional[List[StrictStr]] = None
    uf_prot_rec_fullname: Optional[StrictStr] = None
    uf_keyword: Optional[List[StrictStr]] = None
    uf_gene_name: Optional[StrictStr] = None
    amr: Optional[List[AMRSchema]] = None
    has_amr_info: Optional[StrictBool] = None
    has_proteomics: Optional[StrictBool] = None
    has_fitness: Optional[StrictBool] = None
    has_mutant_growth: Optional[StrictBool] = None
    has_reactions: Optional[StrictBool] = None
    feature_type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "locus_tag",
        "gene_name",
        "alias",
        "product",
        "product_source",
        "start_position",
        "end_position",
        "seq_id",
        "isolate_name",
        "species_scientific_name",
        "species_acronym",
        "uniprot_id",
        "essentiality",
        "cog_funcats",
        "cog_id",
        "kegg",
        "pfam",
        "interpro",
        "ec_number",
        "dbxref",
        "eggnog",
        "inference",
        "ontology_terms",
        "uf_ontology_terms",
        "uf_prot_rec_fullname",
        "uf_keyword",
        "uf_gene_name",
        "amr",
        "has_amr_info",
        "has_proteomics",
        "has_fitness",
        "has_mutant_growth",
        "has_reactions",
        "feature_type",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeneResponseSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in dbxref (list)
        _items = []
        if self.dbxref:
            for _item_dbxref in self.dbxref:
                if _item_dbxref:
                    _items.append(_item_dbxref.to_dict())
            _dict["dbxref"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in amr (list)
        _items = []
        if self.amr:
            for _item_amr in self.amr:
                if _item_amr:
                    _items.append(_item_amr.to_dict())
            _dict["amr"] = _items
        # set to None if locus_tag (nullable) is None
        # and model_fields_set contains the field
        if self.locus_tag is None and "locus_tag" in self.model_fields_set:
            _dict["locus_tag"] = None

        # set to None if gene_name (nullable) is None
        # and model_fields_set contains the field
        if self.gene_name is None and "gene_name" in self.model_fields_set:
            _dict["gene_name"] = None

        # set to None if alias (nullable) is None
        # and model_fields_set contains the field
        if self.alias is None and "alias" in self.model_fields_set:
            _dict["alias"] = None

        # set to None if product (nullable) is None
        # and model_fields_set contains the field
        if self.product is None and "product" in self.model_fields_set:
            _dict["product"] = None

        # set to None if product_source (nullable) is None
        # and model_fields_set contains the field
        if self.product_source is None and "product_source" in self.model_fields_set:
            _dict["product_source"] = None

        # set to None if start_position (nullable) is None
        # and model_fields_set contains the field
        if self.start_position is None and "start_position" in self.model_fields_set:
            _dict["start_position"] = None

        # set to None if end_position (nullable) is None
        # and model_fields_set contains the field
        if self.end_position is None and "end_position" in self.model_fields_set:
            _dict["end_position"] = None

        # set to None if seq_id (nullable) is None
        # and model_fields_set contains the field
        if self.seq_id is None and "seq_id" in self.model_fields_set:
            _dict["seq_id"] = None

        # set to None if isolate_name (nullable) is None
        # and model_fields_set contains the field
        if self.isolate_name is None and "isolate_name" in self.model_fields_set:
            _dict["isolate_name"] = None

        # set to None if species_scientific_name (nullable) is None
        # and model_fields_set contains the field
        if (
            self.species_scientific_name is None
            and "species_scientific_name" in self.model_fields_set
        ):
            _dict["species_scientific_name"] = None

        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if uniprot_id (nullable) is None
        # and model_fields_set contains the field
        if self.uniprot_id is None and "uniprot_id" in self.model_fields_set:
            _dict["uniprot_id"] = None

        # set to None if essentiality (nullable) is None
        # and model_fields_set contains the field
        if self.essentiality is None and "essentiality" in self.model_fields_set:
            _dict["essentiality"] = None

        # set to None if cog_funcats (nullable) is None
        # and model_fields_set contains the field
        if self.cog_funcats is None and "cog_funcats" in self.model_fields_set:
            _dict["cog_funcats"] = None

        # set to None if cog_id (nullable) is None
        # and model_fields_set contains the field
        if self.cog_id is None and "cog_id" in self.model_fields_set:
            _dict["cog_id"] = None

        # set to None if kegg (nullable) is None
        # and model_fields_set contains the field
        if self.kegg is None and "kegg" in self.model_fields_set:
            _dict["kegg"] = None

        # set to None if pfam (nullable) is None
        # and model_fields_set contains the field
        if self.pfam is None and "pfam" in self.model_fields_set:
            _dict["pfam"] = None

        # set to None if interpro (nullable) is None
        # and model_fields_set contains the field
        if self.interpro is None and "interpro" in self.model_fields_set:
            _dict["interpro"] = None

        # set to None if ec_number (nullable) is None
        # and model_fields_set contains the field
        if self.ec_number is None and "ec_number" in self.model_fields_set:
            _dict["ec_number"] = None

        # set to None if dbxref (nullable) is None
        # and model_fields_set contains the field
        if self.dbxref is None and "dbxref" in self.model_fields_set:
            _dict["dbxref"] = None

        # set to None if eggnog (nullable) is None
        # and model_fields_set contains the field
        if self.eggnog is None and "eggnog" in self.model_fields_set:
            _dict["eggnog"] = None

        # set to None if inference (nullable) is None
        # and model_fields_set contains the field
        if self.inference is None and "inference" in self.model_fields_set:
            _dict["inference"] = None

        # set to None if ontology_terms (nullable) is None
        # and model_fields_set contains the field
        if self.ontology_terms is None and "ontology_terms" in self.model_fields_set:
            _dict["ontology_terms"] = None

        # set to None if uf_ontology_terms (nullable) is None
        # and model_fields_set contains the field
        if (
            self.uf_ontology_terms is None
            and "uf_ontology_terms" in self.model_fields_set
        ):
            _dict["uf_ontology_terms"] = None

        # set to None if uf_prot_rec_fullname (nullable) is None
        # and model_fields_set contains the field
        if (
            self.uf_prot_rec_fullname is None
            and "uf_prot_rec_fullname" in self.model_fields_set
        ):
            _dict["uf_prot_rec_fullname"] = None

        # set to None if uf_keyword (nullable) is None
        # and model_fields_set contains the field
        if self.uf_keyword is None and "uf_keyword" in self.model_fields_set:
            _dict["uf_keyword"] = None

        # set to None if uf_gene_name (nullable) is None
        # and model_fields_set contains the field
        if self.uf_gene_name is None and "uf_gene_name" in self.model_fields_set:
            _dict["uf_gene_name"] = None

        # set to None if amr (nullable) is None
        # and model_fields_set contains the field
        if self.amr is None and "amr" in self.model_fields_set:
            _dict["amr"] = None

        # set to None if has_amr_info (nullable) is None
        # and model_fields_set contains the field
        if self.has_amr_info is None and "has_amr_info" in self.model_fields_set:
            _dict["has_amr_info"] = None

        # set to None if has_proteomics (nullable) is None
        # and model_fields_set contains the field
        if self.has_proteomics is None and "has_proteomics" in self.model_fields_set:
            _dict["has_proteomics"] = None

        # set to None if has_fitness (nullable) is None
        # and model_fields_set contains the field
        if self.has_fitness is None and "has_fitness" in self.model_fields_set:
            _dict["has_fitness"] = None

        # set to None if has_mutant_growth (nullable) is None
        # and model_fields_set contains the field
        if (
            self.has_mutant_growth is None
            and "has_mutant_growth" in self.model_fields_set
        ):
            _dict["has_mutant_growth"] = None

        # set to None if has_reactions (nullable) is None
        # and model_fields_set contains the field
        if self.has_reactions is None and "has_reactions" in self.model_fields_set:
            _dict["has_reactions"] = None

        # set to None if feature_type (nullable) is None
        # and model_fields_set contains the field
        if self.feature_type is None and "feature_type" in self.model_fields_set:
            _dict["feature_type"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeneResponseSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "locus_tag": obj.get("locus_tag"),
                "gene_name": obj.get("gene_name"),
                "alias": obj.get("alias"),
                "product": obj.get("product"),
                "product_source": obj.get("product_source"),
                "start_position": obj.get("start_position"),
                "end_position": obj.get("end_position"),
                "seq_id": obj.get("seq_id"),
                "isolate_name": obj.get("isolate_name"),
                "species_scientific_name": obj.get("species_scientific_name"),
                "species_acronym": obj.get("species_acronym"),
                "uniprot_id": obj.get("uniprot_id"),
                "essentiality": obj.get("essentiality"),
                "cog_funcats": obj.get("cog_funcats"),
                "cog_id": obj.get("cog_id"),
                "kegg": obj.get("kegg"),
                "pfam": obj.get("pfam"),
                "interpro": obj.get("interpro"),
                "ec_number": obj.get("ec_number"),
                "dbxref": [DBXRefSchema.from_dict(_item) for _item in obj["dbxref"]]
                if obj.get("dbxref") is not None
                else None,
                "eggnog": obj.get("eggnog"),
                "inference": obj.get("inference"),
                "ontology_terms": obj.get("ontology_terms"),
                "uf_ontology_terms": obj.get("uf_ontology_terms"),
                "uf_prot_rec_fullname": obj.get("uf_prot_rec_fullname"),
                "uf_keyword": obj.get("uf_keyword"),
                "uf_gene_name": obj.get("uf_gene_name"),
                "amr": [AMRSchema.from_dict(_item) for _item in obj["amr"]]
                if obj.get("amr") is not None
                else None,
                "has_amr_info": obj.get("has_amr_info"),
                "has_proteomics": obj.get("has_proteomics"),
                "has_fitness": obj.get("has_fitness"),
                "has_mutant_growth": obj.get("has_mutant_growth"),
                "has_reactions": obj.get("has_reactions"),
                "feature_type": obj.get("feature_type"),
            }
        )
        return _obj



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Set
from typing_extensions import Self


class TTPCompoundInteractionsQuerySchema(BaseModel):
    """
    Schema for getting all interactions for a specific compound.
    """  # noqa: E501

    compound: Optional[StrictStr] = None
    hit_calling: Optional[StrictBool] = None
    species_acronym: Optional[StrictStr] = None
    isolate_name: Optional[StrictStr] = None
    min_ttp_score: Optional[Union[StrictFloat, StrictInt]] = None
    sort_field: Optional[StrictStr] = None
    sort_order: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "compound",
        "hit_calling",
        "species_acronym",
        "isolate_name",
        "min_ttp_score",
        "sort_field",
        "sort_order",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TTPCompoundInteractionsQuerySchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if compound (nullable) is None
        # and model_fields_set contains the field
        if self.compound is None and "compound" in self.model_fields_set:
            _dict["compound"] = None

        # set to None if hit_calling (nullable) is None
        # and model_fields_set contains the field
        if self.hit_calling is None and "hit_calling" in self.model_fields_set:
            _dict["hit_calling"] = None

        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if isolate_name (nullable) is None
        # and model_fields_set contains the field
        if self.isolate_name is None and "isolate_name" in self.model_fields_set:
            _dict["isolate_name"] = None

        # set to None if min_ttp_score (nullable) is None
        # and model_fields_set contains the field
        if self.min_ttp_score is None and "min_ttp_score" in self.model_fields_set:
            _dict["min_ttp_score"] = None

        # set to None if sort_field (nullable) is None
        # and model_fields_set contains the field
        if self.sort_field is None and "sort_field" in self.model_fields_set:
            _dict["sort_field"] = None

        # set to None if sort_order (nullable) is None
        # and model_fields_set contains the field
        if self.sort_order is None and "sort_order" in self.model_fields_set:
            _dict["sort_order"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TTPCompoundInteractionsQuerySchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "compound": obj.get("compound"),
                "hit_calling": obj.get("hit_calling"),
                "species_acronym": obj.get("species_acronym"),
                "isolate_name": obj.get("isolate_name"),
                "min_ttp_score": obj.get("min_ttp_score"),
                "sort_field": obj.get("sort_field"),
                "sort_order": obj.get("sort_order"),
            }
        )
        return _obj
